@@ -19,12 +19,11 @@
  *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
-#include "iteminfo.h"
+#include "resources/iteminfo.h"
 
-#include "itemdb.h"
+#include "resources/itemdb.h"
 
-const std::string&
-ItemInfo::getSprite(Gender gender) const
+const std::string &ItemInfo::getSprite(Gender gender) const
 {
     if (mView)
     {
@@ -46,20 +45,20 @@ void ItemInfo::setWeaponType(int type)
     // See server item.hpp file for type values.
     switch (type)
     {
-        case 0:     // none
+        case WPNTYPE_NONE:
             mAttackType = ACTION_DEFAULT;
             break;
-        case 1:     // knife
-        case 2:     // sword
+        case WPNTYPE_KNIFE:
+        case WPNTYPE_SWORD:
             mAttackType = ACTION_ATTACK_STAB;
             break;
-        case 8:     // projectile
+        case WPNTYPE_THROWN:
             mAttackType = ACTION_ATTACK_THROW;
             break;
-        case 10:    // bow
+        case WPNTYPE_BOW:
             mAttackType = ACTION_ATTACK_BOW;
             break;
-        case 11:    // sickle
+        case WPNTYPE_POLEARM:
             mAttackType = ACTION_ATTACK_SWING;
             break;
         default:
@@ -67,15 +66,12 @@ void ItemInfo::setWeaponType(int type)
     }
 }
 
-void
-ItemInfo::addSound(EquipmentSoundEvent event, const std::string &filename)
+void ItemInfo::addSound(EquipmentSoundEvent event, const std::string &filename)
 {
     mSounds[event].push_back("sfx/" + filename);
 }
 
-
-const std::string&
-ItemInfo::getSound(EquipmentSoundEvent event) const
+const std::string &ItemInfo::getSound(EquipmentSoundEvent event) const
 {
     static const std::string empty;
     std::map< EquipmentSoundEvent, std::vector<std::string> >::const_iterator i;
